1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
|
--- a/etc/Makefile.am
+++ b/etc/Makefile.am
@@ -1,11 +1,9 @@
nobase_dist_sysconf_DATA = \
-report.d/bugzilla.redhat.com.conf \
-report.d/RHEL-bugzilla.redhat.com.conf \
+report.d/bugs.rogentos.ro.conf \
report.conf \
report.d/ftp.conf \
report.d/scp.conf \
report.d/localsave.conf \
-report.d/strata-test.conf \
-report.d/RHEL.conf
+report.d/strata-test.conf
dist_man_MANS = report.conf.5
--- a/etc/report.d/bugs.rogentos.ro.conf
+++ b/etc/report.d/bugs.rogentos.ro.conf
@@ -0,0 +1,7 @@
+[bugs.rogentos.ro]
+# plugin
+plugin=bugzilla
+
+# rhbz url
+bugzilla_host=bugs.rogentos.ro
+
--- a/python/report/plugins/bugzilla/__init__.py
+++ b/python/report/plugins/bugzilla/__init__.py
@@ -1,5 +1,5 @@
"""
A Report plugin to send a report to bugzilla.redhat.com.
Copyright (C) 2009 Red Hat, Inc
Author(s): Gavin Romig-Koch <gavin@redhat.com>
@@ -54,7 +54,7 @@ def displayURL(optionsDict):
def bugURL(optionsDict):
if 'bugURL' in optionsDict:
return optionsDict["bugURL"]
- host = "bugzilla.redhat.com"
+ host = "bugs.rogentos.ro"
if 'bugzilla_host' in optionsDict:
host = optionsDict["bugzilla_host"]
return "https://" + host + "/xmlrpc.cgi"
@@ -149,8 +149,8 @@ def sendToBugzilla(component, signature,
else:
version = filer.getVersion()
- bzfiler = filer.BugzillaFiler("https://bugzilla.redhat.com/xmlrpc.cgi",
- "http://bugzilla.redhat.com",
+ bzfiler = filer.BugzillaFiler("https://bugs.rogentos.ro/xmlrpc.cgi",
+ "http://bugs.rogentos.ro",
version, product)
if not bzfiler or not bzfiler.supportsFiling() or not bzfiler.bugUrl:
|
@@ -1,5 +1,5 @@
"""
- A Report plugin to send a report to bugzilla.redhat.com.
+ A Report plugin to send a report to bugs.rogentos.ro.
Copyright (C) 2009 Red Hat, Inc
Author(s): Gavin Romig-Koch <gavin@redhat.com>